WaveBackground class

A soothing flowing-waves background where sine curves flow horizontally.

Inheritance

Constructors

WaveBackground({Key? key, int waveCount = 3, List<Color> colors = const [Colors.blueAccent, Colors.tealAccent, Colors.cyanAccent], Color? backgroundColor, double speed = 1.0, double amplitude = 25.0, double frequency = 0.005, Widget? child, bool isPaused = false})
const

Properties

amplitude → double
Height of the waves (vertical offset amplitude).
final
backgroundColor → Color?
Background color behind the waves.
final
child → Widget?
Optional child widget on top.
final
colors → List<Color>
The colors of each wave. Should match or exceed waveCount.
final
frequency → double
Frequency factor (width of wave cycles).
final
hashCode → int
The hash code for this object.
no setterinherited
isPaused → bool
Whether the animation is paused.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → double
Speed multiplier for the wave horizontal flow.
final
waveCount → int
The number of wave layers to display.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<WaveBackground>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited