ConstellationBackground class
A particle-web constellation background where nodes move randomly and are linked by dynamic, distance-based lines.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ConstellationBackground
Constructors
-
ConstellationBackground({Key? key, int particleCount = 40, List<
Color> colors = const [Colors.blueAccent, Colors.purpleAccent, Colors.tealAccent], Color lineColor = const Color(0x33FFFFFF), double maxDistance = 100.0, double speed = 1.0, double minRadius = 1.5, double maxRadius = 4.0, Widget? child, bool isPaused = false, bool enableInteraction = true, Color? backgroundColor}) -
const
Properties
- backgroundColor → Color?
-
The background color behind the constellation.
final
- child → Widget?
-
Optional child widget on top.
final
-
colors
→ List<
Color> -
The colors to assign to the particles.
final
- enableInteraction → bool
-
Whether particles respond to mouse hover or touch interaction.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPaused → bool
-
Whether the animation is paused.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lineColor → Color
-
The color of the connecting web lines.
final
- maxDistance → double
-
The maximum distance under which two particles will be connected by a web line.
final
- maxRadius → double
-
Maximum radius of a particle.
final
- minRadius → double
-
Minimum radius of a particle.
final
- particleCount → int
-
The number of particles in the constellation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double
-
Movement speed multiplier.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ConstellationBackground> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited